# Security Policy

## Supported Versions

Only the latest released version is supported - if a major issue appears, old ones will be considered for patching, or yanked.

## Reporting a Vulnerability

Please contact me via email at james+pygoodwe@terminaloutcomes.com